<?php
/**
 * @file
 * Contains theme override functions and preprocess functions for the mobile_jquery theme.
 */
function mobile_jquery_pager($vars) {
	$tags = $vars['tags'];
	$element = $vars['element'];
	$parameters = $vars['parameters'];
	$quantity = $vars['quantity'];
	global $pager_page_array, $pager_total;

	// Calculate various markers within this pager piece:
	// Middle is used to "center" pages around the current page.
	$pager_middle = ceil($quantity / 2);
	// current is the page we are currently paged to
	$pager_current = $pager_page_array[$element] + 1;
	// first is the first page listed by this pager piece (re quantity)
	$pager_first = $pager_current - $pager_middle + 1;
	// last is the last page listed by this pager piece (re quantity)
	$pager_last = $pager_current + $quantity - $pager_middle;
	// max is the maximum page number
	$pager_max = $pager_total[$element];
	// End of marker calculations.

	// Prepare for generation loop.
	$i = $pager_first;
	if ($pager_last > $pager_max) {
		// Adjust "center" if at end of query.
		$i = $i + ($pager_max - $pager_last);
		$pager_last = $pager_max;
	}
	if ($i <= 0) {
		// Adjust "center" if at start of query.
		$pager_last = $pager_last + (1 - $i);
		$i = 1;
	}
	// End of generation loop preparation.

	$li_first = theme('pager_first', array('text' => (isset($tags[0]) ? $tags[0] : t('«')), 'element' => $element, 'parameters' => $parameters, 'attributes' => array('data-role' => 'button', 'data-class' => 'pager-first')));
	$li_previous = theme('pager_previous', array('text' => (isset($tags[1]) ? $tags[1] : t('‹')), 'element' => $element, 'interval' => 1, 'parameters' => $parameters, 'attributes' => array('data-role' => 'button', 'data-class' => 'pager-previous')));
	$li_next = theme('pager_next', array('text' => (isset($tags[3]) ? $tags[3] : t('›')), 'element' => $element, 'interval' => 1, 'parameters' => $parameters, 'attributes' => array('data-role' => 'button', 'data-class' => 'pager-next')));
	$li_last = theme('pager_last', array('text' => (isset($tags[4]) ? $tags[4] : t('»')), 'element' => $element, 'parameters' => $parameters, 'attributes' => array('data-role' => 'button', 'data-class' => 'pager-last')));

	if ($pager_total[$element] > 1) {
		if ($li_first) {
			$items[] = array(
					'class' => array('pager-first'),
					'data' => $li_first,
			);
		}
		if ($li_previous) {
			$items[] = array(
					'class' => array('pager-previous'),
					'data' => $li_previous,
			);
		}

		// When there is more than one page, create the pager list.
		if ($i != $pager_max) {
			if ($i > 1) {
				$items[] = array(
						'class' => array('pager-ellipsis'),
						'data' => l('…', ' ', array('fragment' => TRUE, 'attributes' => array('data-role' => 'button', 'class' => 'pager-ellipsis' ))),
				);
			}
			// Now generate the actual pager piece.
			for (; $i <= $pager_last && $i <= $pager_max; $i++) {
				if ($i < $pager_current) {
					$items[] = array(
							'class' => array('pager-item'),
							'data' => theme('pager_previous', array('text' => $i, 'element' => $element, 'interval' => ($pager_current - $i), 'parameters' => $parameters, 'attributes' => array('data-role' => 'button', 'data-class' => 'pager-previous'))),
					);
				}
				if ($i == $pager_current) {
					$items[] = array(
							'class' => array('pager-current'),
							'data' => l($i, ' ', array('fragment' => TRUE, 'attributes' => array('data-role' => 'button', 'class' => 'pager-current'))),
					);
				}
				if ($i > $pager_current) {
					$items[] = array(
							'class' => array('pager-item'),
							'data' => theme('pager_next', array('text' => $i, 'element' => $element, 'interval' => ($i - $pager_current), 'parameters' => $parameters, 'attributes' => array('data-role' => 'button', 'data-class' => 'pager-next'))),
					);
				}
			}
			if ($i < $pager_max) {
				$items[] = array(
						'class' => array('pager-ellipsis'),
						'data' => l('…', ' ', array('fragment' => TRUE, 'attributes' => array('data-role' => 'button', 'class' => 'pager-ellipsis'))),
				);
			}
		}

		// End generation.
		if ($li_next) {
			$items[] = array(
					'class' => array('pager-next'),
					'data' => $li_next,
			);
		}
		if ($li_last) {
			$items[] = array(
					'class' => array('pager-last'),
					'data' => $li_last,
			);
		}

		$output = '<div data-role="controlgroup" data-type="horizontal" class="pager">';
		foreach ($items as $key => $value) {
			$output .= $items[$key]['data'];
		}
		$output .= '</div>';

		return $output;
	}
}

/**
 * Returns HTML for a link to a specific query result page.
 *
 * @param $vars
 *   An associative array containing:
 *   - text: The link text. Also used to figure out the title attribute of the
 *     link, if it is not provided in $vars['attributes']['title']; in
 *     this case, $vars['text'] must be one of the standard pager link
 *     text strings that would be generated by the pager theme functions, such
 *     as a number or t('« first').
 *   - page_new: The first result to display on the linked page.
 *   - element: An optional integer to distinguish between multiple pagers on
 *     one page.
 *   - parameters: An associative array of query string parameters to append to
 *     the pager link.
 *   - attributes: An associative array of HTML attributes to apply to the
 *     pager link.
 *
 * @see theme_pager()
 *
 * @ingroup themeable
 */
function mobile_jquery_pager_link($vars) {
  $text = $vars['text'];
  $page_new = $vars['page_new'];
  $element = $vars['element'];
  $parameters = $vars['parameters'];
  $attributes = $vars['attributes'];

  $page = isset($_GET['page']) ? $_GET['page'] : '';
  if ($new_page = implode(',', pager_load_array($page_new[$element], $element, explode(',', $page)))) {
    $parameters['page'] = $new_page;
  }

  $query = array();
  if (count($parameters)) {
    $query = drupal_get_query_parameters($parameters, array());
  }
  if ($query_pager = pager_get_query_parameters()) {
    $query = array_merge($query, $query_pager);
  }

  // Set each pager link title
  if (!isset($attributes['title'])) {
    static $titles = NULL;
    static $classes = NULL;
    if (!isset($titles)) {
      $titles = array(
        t('« first') => t('Go to first page'),
        t('‹ previous') => t('Go to previous page'),
        t('next ›') => t('Go to next page'),
        t('last »') => t('Go to last page'),
      );
      $classes = array(
      		t('« first') => 'pager-first',
      		t('‹ previous') => 'pager-previous',
      		t('next ›') => 'pager-next',
      		t('last »') => 'pager-last',
      );
    }
    if (isset($titles[$text])) {
      $attributes['title'] = $titles[$text];
      $attributes['data-class'] = $classes[$text];
      $attributes['data-iconpos'] = 'notext';
    }
    elseif (is_numeric($text)) {
      $attributes['title'] = t('Go to page @number', array('@number' => $text));
    }
  }
  
  $attributes['data-role'] = "button";
  
  return l($text, $_GET['q'], array('attributes' => $attributes, 'query' => $query));
}