;(function ($, Drupal, window, document, undefined) {
  // module global namespace
  Drupal.GSL = Drupal.GSL || {};

  Drupal.GSL.latLng = {};
  Drupal.GSL.settings = {
    "gsl": {
      "google-store-locator-map-container":{
        "datapath":"store-locator\/json",
        "mapzoom":1,
        "maplong":"",
        "maplat":"",
        "search_label":"Find Locations",
        "empty_stores_msg":"There are no stores available.",
        "items_per_panel":"20",
        "loc_aware_zoom":10
      }
    }
  }

  Drupal.GSL.dataSource.prototype.parseStores_ = function(json) {
    console.log('parseStores_');
    var stores = [];

    if (!('stores' in json)) {
      return stores;
    }

    var count = 0;
    // build all our stores
    for ( var i in json.stores) {

      var item = json.stores[i].store;

      if (!item) {
        continue;
      }

      // clone item properties so we can alter for features
      var itemFeatures = ('properties' in item) ? $.extend({},
          item.properties) : {};

      // initialize store properties
      var storeProps = {};

      // extract coordinates
      var Xcoord = item.long;
      var Ycoord = item.lat;

      //console.log('item: ', item);

      // create a unique id
      var store_id = null;

      // set address to views_geojson 'description'
      if ('description' in itemFeatures) {
        storeProps.address = itemFeatures.description;
        delete itemFeatures.description;
      }

      // set latitude and longitude
      var position = new google.maps.LatLng(Ycoord, Xcoord);

      var storeFeatureSet = new storeLocator.FeatureSet;

      // create a FeatureSet since features are required by
      // storeLocator.Store()
      for ( var prop in item) {
        // only add rendered features
        switch (prop) {
        
        case "email":
          var email = item.email;
          storeProps.misc = '<a href="mailto:' + email + '">'
              + email + '</a>';
          break;

        case "phone":
          storeProps.phone = item.phone;
          break;

        case "website":
          var url = item.website.split(',');
          if( jQuery.trim(url) != '' ) {
            storeProps.web = '<a data-role="button" data-mini="true" href="'
              + url[0] + '">website</a>';
          }
          // storeProps.web += '<p class="directions"><a href="#"
          // class="action directions">Directions</a></p>';
          break;

        case "number":
          store_id = item.number;

           break;
        
        case "name":
          storeProps.title = item.name;
          break;

        case "address":
          storeProps.address = item.address;
          break;

        }

      }

      // create our new store
      var store = new storeLocator.Store(store_id, position, storeFeatureSet, storeProps);

      var feature1 = new storeLocator.Feature('1', 'Distance: ' + (store.distanceTo(Drupal.GSL.currentMap.center) * 0.621371).toFixed(2) + ' miles');
      store.getFeatures().add(feature1);

      stores.push(store);
    }
    return stores;
  };

})(jQuery, Drupal, this, this.document);