<?php

/**
 * @file
 * The primary PHP file for this theme.
 */

function moda_menu_tree(array &$variables) {
  return '<ul class="menu nav menu-ul">' . $variables['tree'] . '</ul>';
}

function moda_menu_link(array $variables) {
  $element = $variables['element'];
  $sub_menu = '';

  $options = !empty($element['#localized_options']) ? $element['#localized_options'] : array();

  // Check plain title if "html" is not set, otherwise, filter for XSS attacks.
  $title = empty($options['html']) ? check_plain($element['#title']) : filter_xss_admin($element['#title']);

  // Ensure "html" is now enabled so l() doesn't double encode. This is now
  // safe to do since both check_plain() and filter_xss_admin() encode HTML
  // entities. See: https://www.drupal.org/node/2854978
  $options['html'] = TRUE;

  $href = $element['#href'];
  $attributes = !empty($element['#attributes']) ? $element['#attributes'] : array();

  if ($element['#below']) {
    // Prevent dropdown functions from being added to management menu so it
    // does not affect the navbar module.
    if (($element['#original_link']['menu_name'] == 'management') && (module_exists('navbar'))) {
      $sub_menu = drupal_render($element['#below']);
    }
    elseif ((!empty($element['#original_link']['depth'])) && ($element['#original_link']['depth'] == 1)) {
      // Add our own wrapper.
      unset($element['#below']['#theme_wrappers']);
      //$sub_menu = '<ul class="dropdown-menu">' . drupal_render($element['#below']) . '</ul>';
      $sub_menu = '<div class="menu-dropdown submenu w300"><ul class="submenu-list">' . drupal_render($element['#below']) . '</ul></div>';

      // Generate as standard dropdown.
      $title .= ' <span class="caret"></span>';
      //$attributes['class'][] = 'dropdown';
      $attributes['class'][] = 'has-dropdown';

      // Set dropdown trigger element to # to prevent inadvertant page loading
      // when a submenu link is clicked.
      $options['attributes']['data-target'] = '#';
      $options['attributes']['class'][] = 'dropdown-toggle';
      $options['attributes']['data-hover'] = 'dropdown';
    }
  }

  return '<li' . drupal_attributes($attributes) . '>' . l($title, $href, $options) . $sub_menu . "</li>\n";
}

function moda_theme_registry_alter(&$registry) {
  // Re-run Menu View's theme registry alters.
  if (function_exists('menu_views_theme_registry_alter')) {
    menu_views_theme_registry_alter($registry);
  }
}

function moda_date_display_range($variables) {
  $date1 = $variables['date1'];
  $date2 = $variables['date2'];
  $timezone = $variables['timezone'];
  $attributes_start = $variables['attributes_start'];
  $attributes_end = $variables['attributes_end'];
  $show_remaining_days = $variables['show_remaining_days'];

  $start_date = '<span class="date-display-start"' . drupal_attributes($attributes_start) . '>' . $date1 . '</span>';
  $end_date = '<span class="date-display-end"' . drupal_attributes($attributes_end) . '>' . $date2 . $timezone . '</span>';

  // If microdata attributes for the start date property have been passed in,
  // add the microdata in meta tags.
  if (!empty($variables['add_microdata'])) {
    $start_date .= '<meta' . drupal_attributes($variables['microdata']['value']['#attributes']) . '/>';
    $end_date .= '<meta' . drupal_attributes($variables['microdata']['value2']['#attributes']) . '/>';
  }

  // Wrap the result with the attributes.
  $output = '<span class="date-display-range">' . t('!start-date-!end-date', array(
    '!start-date' => $start_date,
    '!end-date' => $end_date,
  )) . '</span>';

  // Add remaining message and return.
  return $output . $show_remaining_days;
}



function moda_preprocess_comment_wrapper(&$variables) {
  // Provide contextual information.
  //hide($variables['content']['comment_form']);
  $variables['node'] = $variables['content']['#node'];
  $variables['display_mode'] = variable_get('comment_default_mode_' . $variables['node']->type, COMMENT_MODE_THREADED);
  // The comment form is optional and may not exist.
  //$variables['content'] += array('comment_form' => array());
  $commentsform = $variables['content']['comment_form'];
  $commentslist = $variables['content']['comments'];
  $variables['content']['comments'] = array(
    '#type' => 'fieldset',
    '#title' => format_plural($variables['node']->comment_count, '<i class="far fa-comment"></i> 1 comment', '<i class="far fa-comment"></i> @count comments'),
    '#weight' => 0,
    '#collapsible' => TRUE, // does not work and thus is not necessary
    '#collapsed' => TRUE, // does not work and thus is not necessary
    '#pre_render' => array(),
    '#attributes' => array(),
  );
  // Make it manually collapsible as we cannot use #collapsible without the
  // FAPI element processor.
  $variables['content']['comments']['#attached']['library'][] = array('system', 'drupal.collapse');
  $variables['content']['comments']['#attributes']['class'][] = 'collapsible';
  $variables['content']['comments']['#attributes']['class'][] = 'collapsed';
  $variables['content']['comments']['commentslist'] = $commentslist;
  //$variables['content']['comments']['comment_form'] = $commentsform;
  //var_dump($variables['content']['comments']);
}

function moda_form_alter(&$form, &$form_state, $form_id) {
  if ($form_id == 'custom_search_blocks_form_3') {
    $form['actions']['submit']['#value'] = html_entity_decode('&#xf002;');
  }
} 